==> open_watcom_1.4.0-src.zip: bld/clib/mbyte/c/mbislead.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#include "variety.h"
#include <mbstring.h>
#include "mbchar.h"
#include "rtinit.h"

_WCRTLINK unsigned char         __MBCSIsTable[257];

/**
 * Determine whether or not the specified byte is a lead byte.
 */

_WCRTLINK int (_ismbblead)( const unsigned int ch )
{
    return( __MBCSIsTable[ch+1] & _MB_LEAD );
}

/**
 * If this module is linked in, the startup code will call this function,
 * which will initialize the default multibyte code page.
 */

static void __mbInitOnStartup( void )
{
    __mbinit( 0 );
}

AXI( __mbInitOnStartup, INIT_PRIORITY_LIBRARY )

==> open_watcom_1.5.0-src.zip: bld/clib/mbyte/c/mbislead.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


#include "variety.h"
#include <mbstring.h>
#include "mbchar.h"
#include "rtinit.h"

_WCRTLINKD unsigned char        __MBCSIsTable[257];

/**
 * Determine whether or not the specified byte is a lead byte.
 */

_WCRTLINK int (_ismbblead)( const unsigned int ch )
{
    return( __MBCSIsTable[ch+1] & _MB_LEAD );
}

/**
 * If this module is linked in, the startup code will call this function,
 * which will initialize the default multibyte code page.
 */

static void __mbInitOnStartup( void )
{
    __mbinit( 0 );
}

AXI( __mbInitOnStartup, INIT_PRIORITY_LIBRARY )
